#ifndef NT2_INCLUDE_FUNCTIONS_FRAC_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FRAC_HPP_INCLUDED

#include <nt2/ieee/include/functions/frac.hpp>

#endif
